@@ -15,6 +15,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import codecs
+from codecs import CodecInfo
 import contextlib
 from io import StringIO
 import os
@@ -22,15 +23,12 @@ import shutil
 import sys
 import tempfile
 import unittest
-import warnings
-from codecs import CodecInfo
 
 import yaml
 
 from yamllint import linter
 from yamllint.config import YamlLintConfig
 
-
 # Encoding related stuff:
 UTF_CODECS = (
     'utf_32_be',
@@ -91,17 +89,11 @@ def register_test_codecs():
 
 
 def unregister_test_codecs():
-    if sys.version_info >= (3, 10, 0):
-        codecs.unregister(test_codec_infos.get)
-    else:
-        warnings.warn(
-            "This version of Python doesn’t allow us to unregister codecs.",
-            stacklevel=1
-        )
+    codecs.unregister(test_codec_infos.get)
 
 
 def is_test_codec(codec):
-    return codec in test_codec_infos.keys()
+    return codec in test_codec_infos
 
 
 def built_in_equivalent_of_test_codec(test_codec):
@@ -112,10 +104,7 @@ def built_in_equivalent_of_test_codec(test_codec):
 
 
 def uses_bom(codec):
-    for suffix in ('_32', '_16', '_sig'):
-        if codec.endswith(suffix):
-            return True
-    return False
+    return any(codec.endswith(suffix) for suffix in ('_32', '_16', '_sig'))
 
 
 def encoding_detectable(string, codec):
@@ -193,17 +182,17 @@ class RuleTestCase(unittest.TestCase):
 
     def check(self, source, conf, **kwargs):
         expected_problems = []
-        for key in kwargs:
+        for key, value in kwargs.items():
             assert key.startswith('problem')
-            if len(kwargs[key]) > 2:
-                if kwargs[key][2] == 'syntax':
+            if len(value) > 2:
+                if value[2] == 'syntax':
                     rule_id = None
                 else:
-                    rule_id = kwargs[key][2]
+                    rule_id = value[2]
             else:
                 rule_id = self.rule_id
             expected_problems.append(linter.LintProblem(
-                kwargs[key][0], kwargs[key][1], rule=rule_id))
+                value[0], value[1], rule=rule_id))
         expected_problems.sort()
 
         real_problems = list(linter.run(source, self.build_fake_config(conf)))
