@@ -30,7 +30,8 @@ def find_files_recursively(items, conf):
             for root, _dirnames, filenames in os.walk(item):
                 for f in filenames:
                     filepath = os.path.join(root, f)
-                    if conf.is_yaml_file(filepath):
+                    if (conf.is_yaml_file(filepath) and
+                            not conf.is_file_ignored(filepath)):
                         yield filepath
         else:
             yield item
@@ -78,9 +79,9 @@ class Format:
 
     @staticmethod
     def github(problem, filename):
-        line = f'::{problem.level} file={filename},' \
-               f'line={problem.line},col={problem.column}' \
-               f'::{problem.line}:{problem.column} '
+        line = (f'::{problem.level} file={filename},'
+                f'line={problem.line},col={problem.column}'
+                f'::{problem.line}:{problem.column} ')
         if problem.rule:
             line += f'[{problem.rule}] '
         line += problem.desc
@@ -216,9 +217,9 @@ def run(argv=None):
     max_level = 0
 
     for file in find_files_recursively(args.files, conf):
-        filepath = file[2:] if file.startswith('./') else file
+        filepath = file.removeprefix('./')
         try:
-            with open(file, newline='') as f:
+            with open(file, mode='rb') as f:
                 problems = linter.run(f, conf, filepath)
         except OSError as e:
             print(e, file=sys.stderr)
@@ -230,7 +231,10 @@ def run(argv=None):
     # read yaml from stdin
     if args.stdin:
         try:
-            problems = linter.run(sys.stdin, conf, '')
+            # The .buffer part makes sure that we get the raw bytes. We need to
+            # get the raw bytes so that we can autodetect the character
+            # encoding.
+            problems = linter.run(sys.stdin.buffer, conf, '')
         except OSError as e:
             print(e, file=sys.stderr)
             sys.exit(-1)
